@@ -9,7 +9,6 @@ import (
 	corev1 "k8s.io/api/core/v1"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/util/intstr"
 )
 
 func TestDesiredDNSDaemonset(t *testing.T) {
@@ -157,22 +156,52 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 			expect: true,
 		},
 		{
-			description: "if the readiness probe endpoint changes",
+			description: "if an unexpected additional container is added",
 			mutate: func(daemonset *appsv1.DaemonSet) {
-				daemonset.Spec.Template.Spec.Containers[0].ReadinessProbe.Handler.HTTPGet.Path = "/ready"
+				containers := daemonset.Spec.Template.Spec.Containers
+				daemonset.Spec.Template.Spec.Containers = append(containers, corev1.Container{
+					Name:  "foo",
+					Image: "bar",
+				})
 			},
 			expect: true,
 		},
 		{
-			description: "if the readiness probe period changes",
+			description: "if the config-volume default mode value is defaulted",
 			mutate: func(daemonset *appsv1.DaemonSet) {
-				daemonset.Spec.Template.Spec.Containers[0].ReadinessProbe.PeriodSeconds = 2
+				newVal := volumeDefaultMode
+				daemonset.Spec.Template.Spec.Volumes[0].ConfigMap.DefaultMode = &newVal
+			},
+			expect: false,
+		},
+		{
+			description: "if the config-volume default mode value changes",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				newVal := int32(0)
+				daemonset.Spec.Template.Spec.Volumes[0].ConfigMap.DefaultMode = &newVal
+			},
+			expect: true,
+		},
+		{
+			description: "if the metrics-tls default mode value is defaulted",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				newVal := volumeDefaultMode
+				daemonset.Spec.Template.Spec.Volumes[2].Secret.DefaultMode = &newVal
+			},
+			expect: false,
+		},
+		{
+			description: "if the metrics-tls default mode value changes",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				newVal := int32(0)
+				daemonset.Spec.Template.Spec.Volumes[2].Secret.DefaultMode = &newVal
 			},
 			expect: true,
 		},
 	}
 
 	for _, tc := range testCases {
+		hostPathFile := corev1.HostPathFile
 		original := appsv1.DaemonSet{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "dns-original",
@@ -190,18 +219,6 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 									"a",
 									"b",
 								},
-								ReadinessProbe: &corev1.Probe{
-									PeriodSeconds: 10,
-									Handler: corev1.Handler{
-										HTTPGet: &corev1.HTTPGetAction{
-											Path: "/health",
-											Port: intstr.IntOrString{
-												IntVal: int32(8080),
-											},
-											Scheme: "HTTP",
-										},
-									},
-								},
 							},
 							{
 								Name:  "dns-node-resolver",
@@ -223,6 +240,35 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 						NodeSelector: map[string]string{
 							"beta.kubernetes.io/os": "linux",
 						},
+						Volumes: []corev1.Volume{
+							{
+								Name: "config-volume",
+								VolumeSource: corev1.VolumeSource{
+									ConfigMap: &corev1.ConfigMapVolumeSource{
+										LocalObjectReference: corev1.LocalObjectReference{
+											Name: "dns-default",
+										},
+									},
+								},
+							},
+							{
+								Name: "hosts-file",
+								VolumeSource: corev1.VolumeSource{
+									HostPath: &corev1.HostPathVolumeSource{
+										Path: "/etc/hosts",
+										Type: &hostPathFile,
+									},
+								},
+							},
+							{
+								Name: "metrics-tls",
+								VolumeSource: corev1.VolumeSource{
+									Secret: &corev1.SecretVolumeSource{
+										SecretName: "dns-default-metrics-tls",
+									},
+								},
+							},
+						},
 					},
 				},
 			},
